Installation
============


The easiest method is to install directly from pypi.org using `pip`::

    pip install lstail


If you prefer, you can download Lstail and install it directly from source::

    python setup.py install
